@@ -1,5 +1,6 @@
 import os
 import time
+import sys
 from multiprocessing import Queue
 from multiprocessing import Process
 from queue import Empty
@@ -8,6 +9,7 @@ from mpscreen.components import buffer, bufferServer, line, lineServer, Vstr, Vi
 
 consoleEscape = r'\u001b\[.+m'
 
+
 def _screenMainLoop(s):
     s.getTerminalSize()
     s.refresh(f=True)
@@ -21,9 +23,10 @@ def _screenMainLoop(s):
             s.refresh(f=True)
         try:
             msg = s.q.get(timeout=0.5)
+            sys.stderr.write(s.q.qsize())
         except Empty:
             s.refresh()
-        if  isinstance(msg, list) and len(msg) > 0:
+        if isinstance(msg, list) and len(msg) > 0:
             if msg[0] == 'Q':
                 return
             elem = s.getElem(msg[0])
